(function ($, Drupal) {
  Drupal.behaviors.media_folder_management = {
    attach(context) {
      const getQueryParam = function (url, key) {
        const queryStartPos = url.indexOf('?');
        if (queryStartPos === -1) {
          return;
        }
        const params = url.substring(queryStartPos + 1).split('&');
        for (let i = 0; i < params.length; i++) {
          const pairs = params[i].split('=');
          if (decodeURIComponent(pairs.shift()) === key) {
            return decodeURIComponent(pairs.join('='));
          }
        }
      };

      if ($(context)[0].nodeName === '#document') {
        $(once('media-file-explorer', '#media-file-explorer', context)).each(
          function () {
            $(window).on('load', function () {
              const url = window.location.pathname;
              const state = {
                type: 'media-file-explorer',
                url,
                page: document.title,
              };
              window.history.pushState(state, document.title, url);
            });
            $(window).on('popstate', function () {
              if (
                window.history.state &&
                window.history.state.type === 'media-file-explorer'
              ) {
                $(this).ajaxLoad(window.history.state.url);
              }
            });
          },
        );

        if (
          $('.folder-breadcrumb').find('.folder-breadcrumb-inner').width() >
          $('.folder-breadcrumb').width()
        ) {
          $('.folder-breadcrumb').addClass('overflow');
        } else {
          $('.folder-breadcrumb').removeClass('overflow');
        }

        $(
          once(
            'subfolders-folder-icon',
            '#subfolders .folder a.folder-icon',
            context,
          ),
        ).click(function (event) {
          const folder = $(this).parent('.folder');

          $('#subfolders .folder a.selected')
            .not($(this))
            .removeClass('selected');
          $('#subfolders .folder.selected').not(folder).removeClass('selected');

          $('#folders-details span').html('');
          $(this).toggleClass('selected');
          folder.toggleClass('selected');

          const text = $(this).find('span.title')[0].textContent;

          if ($(this).hasClass('selected')) {
            let title = '';
            const dataCount = $(this).attr('data-count');
            const dataExtension = $(this).attr('data-ext');
            const dataSize = $(this).attr('data-size');
            const lockedBy = $(this).attr('data-locked-by');

            if (dataCount) {
              title = `<strong>${text}</strong> (${dataCount} ${Drupal.t('items')})`;
            } else if (dataExtension) {
              title = `<strong>${text}</strong> (${dataExtension} ${Drupal.t('file')} ; ${dataSize})`;
            } else {
              title = `<strong>${text}</strong>`;
            }

            if (lockedBy) {
              title += ` (${lockedBy})`;
            }

            $('#folders-details span.details').html(title);
          }

          event.preventDefault();
          event.stopPropagation();
        });

        $(
          once('navbar-expand', '#explorer #navbar > ul li > span', context),
        ).click(function (event) {
          $(this).parent().toggleClass('active-trail');
        });

        $(
          once(
            'subfolders-back',
            '#media-file-explorer .top-bar .up-button',
            context,
          ),
        ).click(function (event) {
          event.preventDefault();
          event.stopPropagation();

          const url = $(this).find('a').attr('href');
          const state = {
            type: 'media-file-explorer',
            url,
          };
          window.history.pushState(state, document.title, url);
          $(this).ajaxLoad(url);
        });

        $(
          once(
            'subfolders-breadcrumb',
            '#navbar a, #media-file-explorer .top-bar .folder-breadcrumb a',
            context,
          ),
        ).click(function (event) {
          event.preventDefault();
          event.stopPropagation();

          const url = $(this).attr('href');
          const state = {
            type: 'media-file-explorer',
            url,
          };
          window.history.pushState(state, document.title, url);
          $(this).ajaxLoad(url);
        });

        $(once('subfolders-folder', '#subfolders .folder', context)).dblclick(
          function (event) {
            event.preventDefault();
            event.stopPropagation();

            if ($(this).find('a').hasClass('folder-icon-file')) {
              window.location.href = $(this).find('a').attr('href');
            } else {
              const url = $(this).find('a').attr('href');
              const title = $(this).find('.title')[0].textContent;
              const state = {
                type: 'media-file-explorer',
                url,
                page: title,
              };
              window.history.pushState(state, title, url);
              $(this).ajaxLoad(url);
            }
          },
        );

        $(
          once(
            'subfolders-buttons',
            '#media-file-explorer .top-bar .buttons a',
            context,
          ),
        ).click(function (event) {
          event.preventDefault();
          event.stopPropagation();

          const url = $(this).attr('href');
          const a = document.createElement('A');
          a.href = url;
          $('body').addClass('loading');
          $.ajax({
            url: `${a.pathname}/ajax`,
            type: 'GET',
            cache: false,
            success(result) {
              if (result.name === 'view-type') {
                $('#media-file-explorer').removeClass().addClass(result.value);
              }
              $(this).ajaxLoad(getQueryParam(url, 'destination'));
            },
            error(result) {
              const messages = new Drupal.Message();
              messages.add(Drupal.t('An error occurred'), {
                type: 'error',
              });
              $('body').removeClass('loading');
            },
          });
        });

        if ($('form.media-folders-search-form #edit-search').length) {
          $('form.media-folders-search-form #edit-search').on(
            'keyup',
            function () {
              const filter = $(this)[0].value.toUpperCase();
              $('#subfolders .folder').each(function () {
                const txtValue = $(this).find('span.title')[0].textContent;
                if (txtValue.toUpperCase().indexOf(filter) > -1) {
                  $(this).show();
                } else {
                  $(this).hide();
                }
              });
            },
          );
        }

        $(window).on('dialogopen', (e, ui) => {
          Drupal.attachBehaviors();
        });

        $(once('subfolders-share', '.permalink .copy-link', context)).on(
          'click',
          function (event) {
            event.preventDefault();
            event.stopPropagation();

            $('.permalink .text-link').select();
            document.execCommand('copy');
            $(this).attr('tooltip', Drupal.t('Copied!'));
          },
        );
      }
    },
  };
})(jQuery, Drupal);
