<?php

namespace Drupal\media_folder_management\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBundleBase;
use Drupal\Core\Entity\EntityWithPluginCollectionInterface;
use Drupal\media_folder_management\MediaFolderFileTypeInterface;

/**
 * Defines the Media folder file type configuration entity.
 *
 * @ConfigEntityType(
 *   id = "media_folder_file_type",
 *   label = @Translation("Media folder file type"),
 *   label_collection = @Translation("Media folder file types"),
 *   label_singular = @Translation("Media folder file type"),
 *   label_plural = @Translation("Media folder file types"),
 *   label_count = @PluralTranslation(
 *     singular = "@count media folder file type",
 *     plural = "@count media folder file types"
 *   ),
 *   handlers = {
 *     "access" = "Drupal\media_folder_management\Entity\Access\MediaFolderFileTypeAccessControlHandler",
 *     "form" = {
 *       "add" = "Drupal\media_folder_management\Entity\Form\MediaFolderFileTypeForm",
 *       "edit" = "Drupal\media_folder_management\Entity\Form\MediaFolderFileTypeForm",
 *       "delete" = "Drupal\media_folder_management\Entity\Form\MediaFolderFileTypeDeleteConfirmForm"
 *     },
 *     "list_builder" = "Drupal\media_folder_management\Entity\ListBuilder\MediaFolderFileTypeListBuilder",
 *     "route_provider" = {
 *       "html" = "Drupal\Core\Entity\Routing\DefaultHtmlRouteProvider",
 *     }
 *   },
 *   admin_permission = "administer media folder files",
 *   config_prefix = "type",
 *   bundle_of = "media_folder_file",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "status" = "status",
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "description",
 *     "new_revision",
 *     "status",
 *   },
 *   links = {
 *     "add-form" = "/admin/structure/media-folder-file/add",
 *     "edit-form" = "/admin/structure/media-folder-file/manage/{media_folder_file_type}",
 *     "delete-form" = "/admin/structure/media-folder-file/manage/{media_folder_file_type}/delete",
 *     "collection" = "/admin/structure/media-folder-file",
 *   },
 * )
 */
class MediaFolderFileType extends ConfigEntityBundleBase implements MediaFolderFileTypeInterface, EntityWithPluginCollectionInterface {

  /**
   * The machine name of this Media folder file type.
   *
   * @var string
   */
  protected $id;

  /**
   * The human-readable name of the Media folder file type.
   *
   * @var string
   */
  protected $label;

  /**
   * A brief description of this Media folder file type.
   *
   * @var string
   */
  protected $description;

  /**
   * Whether Media folder file items should be published by default.
   *
   * @var bool
   */
  protected $status = TRUE;

  /**
   * Default value of the 'Create new revision'.
   *
   * @var bool
   */
  protected $new_revision = TRUE;

  /**
   * {@inheritdoc}
   */
  public function getPluginCollections() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->description;
  }

  /**
   * {@inheritdoc}
   */
  public function setDescription($description) {
    return $this->set('description', $description);
  }

  /**
   * {@inheritdoc}
   */
  public function getStatus() {
    return $this->status;
  }

  /**
   * {@inheritdoc}
   */
  public function shouldCreateNewRevision() {
    return $this->new_revision;
  }

  /**
   * {@inheritdoc}
   */
  public function setNewRevision($new_revision) {
    return $this->set('new_revision', $new_revision);
  }

}
