<?php

namespace Drupal\media_folder_management;

use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\RevisionLogInterface;
use Drupal\user\EntityOwnerInterface;
use Drupal\Core\Entity\EntityPublishedInterface;

/**
 * Provides an interface defining an entity for media folder file items.
 */
interface MediaFolderFileInterface extends ContentEntityInterface, EntityChangedInterface, RevisionLogInterface, EntityOwnerInterface, EntityPublishedInterface {

  /**
   * Gets the media folder file item name.
   *
   * @return string
   *   The name of the media folder file item.
   */
  public function getName();

  /**
   * Sets the media folder file item name.
   *
   * @param string $name
   *   The name of the media folder file item.
   *
   * @return $this
   */
  public function setName($name);

  /**
   * Returns the media folder file item creation timestamp.
   *
   * @return int
   *   Creation timestamp of the media folder file item.
   */
  public function getCreatedTime();

  /**
   * Sets the media folder file item creation timestamp.
   *
   * @param int $timestamp
   *   The media folder file creation timestamp.
   *
   * @return \Drupal\media_folder_management\MediaFolderFileInterface
   *   The called media folder file item.
   */
  public function setCreatedTime($timestamp);

}
